#[non_exhaustive]#[repr(u32)]pub enum JxlColorProfileTarget {
JXL_COLOR_PROFILE_TARGET_ORIGINAL = 0,
JXL_COLOR_PROFILE_TARGET_DATA = 1,
}Expand description
Defines which color profile to get: the profile from the codestream metadata header, which represents the color profile of the original image, or the color profile from the pixel data produced by the decoder. Both are the same if the JxlBasicInfo has uses_original_profile set.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
JXL_COLOR_PROFILE_TARGET_ORIGINAL = 0
Get the color profile of the original image from the metadata.
JXL_COLOR_PROFILE_TARGET_DATA = 1
Get the color profile of the pixel data the decoder outputs.