#[non_exhaustive]#[repr(u32)]pub enum JxlDataType {
JXL_TYPE_FLOAT = 0,
JXL_TYPE_UINT8 = 2,
JXL_TYPE_UINT16 = 3,
JXL_TYPE_FLOAT16 = 5,
}Expand description
Data type for the sample values per channel per pixel.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
JXL_TYPE_FLOAT = 0
Use 32-bit single-precision floating point values, with range 0.0-1.0 (within gamut, may go outside this range for wide color gamut). Floating point output, either ::JXL_TYPE_FLOAT or ::JXL_TYPE_FLOAT16, is recommended for HDR and wide gamut images when color profile conversion is required.
JXL_TYPE_UINT8 = 2
Use type uint8_t. May clip wide color gamut data.
JXL_TYPE_UINT16 = 3
Use type uint16_t. May clip wide color gamut data.
JXL_TYPE_FLOAT16 = 5
Use 16-bit IEEE 754 half-precision floating point values