#[non_exhaustive]#[repr(u32)]pub enum JxlEncoderStatus {
JXL_ENC_SUCCESS = 0,
JXL_ENC_ERROR = 1,
JXL_ENC_NEED_MORE_OUTPUT = 2,
}Expand description
Return value for multiple encoder functions.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
JXL_ENC_SUCCESS = 0
Function call finished successfully, or encoding is finished and there is nothing more to be done.
JXL_ENC_ERROR = 1
An error occurred, for example out of memory.
JXL_ENC_NEED_MORE_OUTPUT = 2
The encoder needs more output buffer to continue encoding.