JxlDecoderGetBasicInfo

Function JxlDecoderGetBasicInfo 

pub unsafe extern "C" fn JxlDecoderGetBasicInfo(
    dec: *const JxlDecoder,
    info: *mut JxlBasicInfo,
) -> JxlDecoderStatus
Outputs the basic image information, such as image dimensions, bit depth and all other JxlBasicInfo fields, if available.

@param dec decoder object @param info struct to copy the information into, or NULL to only check whether the information is available through the return value. @return ::JXL_DEC_SUCCESS if the value is available, @ref JXL_DEC_NEED_MORE_INPUT if not yet available, ::JXL_DEC_ERROR in case of other error conditions.