JxlDecoderGetBoxSizeContents

Function JxlDecoderGetBoxSizeContents 

pub unsafe extern "C" fn JxlDecoderGetBoxSizeContents(
    dec: *const JxlDecoder,
    size: *mut u64,
) -> JxlDecoderStatus
Returns the size of the contents of a box, after the @ref JXL_DEC_BOX event. This does not include any of the headers of the box. For compressed “brob” boxes, this is the size of the compressed content. Even when @ref JxlDecoderSetDecompressBoxes is enabled, the return value of function does not change, and the decompressed size is not known before it has already been decompressed and output.

@param dec decoder object @param size size of the payload of the box in bytes @return @ref JXL_DEC_ERROR if no box size is available, @ref JXL_DEC_SUCCESS otherwise.