pub unsafe extern "C" fn JxlDecoderGetFrameHeader(
dec: *const JxlDecoder,
header: *mut JxlFrameHeader,
) -> JxlDecoderStatusExpand description
Outputs the information from the frame, such as duration when have_animation. This function can be called when ::JXL_DEC_FRAME occurred for the current frame, even when have_animation in the JxlBasicInfo is JXL_FALSE.
@param dec decoder object @param header struct to copy the information into, or NULL to only check whether the information is available through the return value. @return ::JXL_DEC_SUCCESS if the value is available, @ref JXL_DEC_NEED_MORE_INPUT if not yet available, ::JXL_DEC_ERROR in case of other error conditions.