JxlDecoderGetFrameName

Function JxlDecoderGetFrameName 

pub unsafe extern "C" fn JxlDecoderGetFrameName(
    dec: *const JxlDecoder,
    name: *mut c_char,
    size: usize,
) -> JxlDecoderStatus
Outputs name for the current frame. The buffer for name must have at least name_length + 1 bytes allocated, gotten from the associated JxlFrameHeader.

@param dec decoder object @param name buffer to copy the name into @param size size of the name buffer in bytes, including zero termination character, so this must be at least @ref JxlFrameHeader.name_length + 1. @return ::JXL_DEC_SUCCESS if the value is available, @ref JXL_DEC_NEED_MORE_INPUT if not yet available, ::JXL_DEC_ERROR in case of other error conditions.