pub unsafe extern "C" fn JxlDecoderSetDesiredIntensityTarget(
dec: *mut JxlDecoder,
desired_intensity_target: f32,
) -> JxlDecoderStatusExpand description
Requests that the decoder perform tone mapping to the peak display luminance passed as @c desired_intensity_target, if appropriate. @note This is provided for convenience and the exact tone mapping that is performed is not meant to be considered authoritative in any way. It may change from version to version. @param dec decoder object @param desired_intensity_target the intended target peak luminance @return ::JXL_DEC_SUCCESS if the preference was set successfully, @ref JXL_DEC_ERROR otherwise.