JxlDecoderSetImageOutBitDepth

Function JxlDecoderSetImageOutBitDepth 

pub unsafe extern "C" fn JxlDecoderSetImageOutBitDepth(
    dec: *mut JxlDecoder,
    bit_depth: *const JxlBitDepth,
) -> JxlDecoderStatus
Sets the bit depth of the output buffer or callback.

Can be called after @ref JxlDecoderSetImageOutBuffer or @ref JxlDecoderSetImageOutCallback. For float pixel data types, only the default ::JXL_BIT_DEPTH_FROM_PIXEL_FORMAT setting is supported.

@param dec decoder object @param bit_depth the bit depth setting of the pixel output @return ::JXL_DEC_SUCCESS on success, ::JXL_DEC_ERROR on error, such as incompatible custom bit depth and pixel data type.