JxlDecoderSetMultithreadedImageOutCallback

Function JxlDecoderSetMultithreadedImageOutCallback 

pub unsafe extern "C" fn JxlDecoderSetMultithreadedImageOutCallback(
    dec: *mut JxlDecoder,
    format: *const JxlPixelFormat,
    init_callback: JxlImageOutInitCallback,
    run_callback: JxlImageOutRunCallback,
    destroy_callback: JxlImageOutDestroyCallback,
    init_opaque: *mut c_void,
) -> JxlDecoderStatus
Similar to @ref JxlDecoderSetImageOutCallback except that the callback is allowed an initialization phase during which it is informed of how many threads will call it concurrently, and those calls are further informed of which thread they are occurring in.

@param dec decoder object @param format format of the pixels. Object owned by user; its contents are copied internally. @param init_callback initialization callback. @param run_callback the callback function receiving partial scanlines of pixel data. @param destroy_callback clean-up callback invoked after all calls to @c run_callback. May be NULL if no clean-up is necessary. @param init_opaque optional user data passed to @c init_callback, may be NULL (unlike the return value from @c init_callback which may only be NULL if initialization failed). @return ::JXL_DEC_SUCCESS on success, ::JXL_DEC_ERROR on error, such as @ref JxlDecoderSetImageOutBuffer having already been called.