JxlDecoderSetPreviewOutBuffer

Function JxlDecoderSetPreviewOutBuffer 

pub unsafe extern "C" fn JxlDecoderSetPreviewOutBuffer(
    dec: *mut JxlDecoder,
    format: *const JxlPixelFormat,
    buffer: *mut c_void,
    size: usize,
) -> JxlDecoderStatus
Sets the buffer to write the low-resolution preview image to. The size of the buffer must be at least as large as given by @ref JxlDecoderPreviewOutBufferSize. The buffer follows the format described by @ref JxlPixelFormat. The preview image dimensions are given by the @ref JxlPreviewHeader. The buffer is owned by the caller.

@param dec decoder object @param format format of pixels. Object owned by user and its contents are copied internally. @param buffer buffer type to output the pixel data to @param size size of buffer in bytes @return ::JXL_DEC_SUCCESS on success, ::JXL_DEC_ERROR on error, such as size too small.