pub unsafe extern "C" fn JxlDecoderSetProgressiveDetail(
dec: *mut JxlDecoder,
detail: JxlProgressiveDetail,
) -> JxlDecoderStatusExpand description
Configures at which progressive steps in frame decoding these @ref
JXL_DEC_FRAME_PROGRESSION event occurs. The default value for the level
of detail if this function is never called is kDC.
@param dec decoder object @param detail at which level of detail to trigger @ref JXL_DEC_FRAME_PROGRESSION @return ::JXL_DEC_SUCCESS on success, ::JXL_DEC_ERROR on error, such as an invalid value for the progressive detail.