JxlDecoderSkipCurrentFrame

Function JxlDecoderSkipCurrentFrame 

pub unsafe extern "C" fn JxlDecoderSkipCurrentFrame(
    dec: *mut JxlDecoder,
) -> JxlDecoderStatus
Skips processing the current frame. Can be called after frame processing already started, signaled by a ::JXL_DEC_NEED_IMAGE_OUT_BUFFER event, but before the corresponding ::JXL_DEC_FULL_IMAGE event. The next signaled event will be another ::JXL_DEC_FRAME, or ::JXL_DEC_SUCCESS if there are no more frames. If pixel data is required from the already processed part of the frame, @ref JxlDecoderFlushImage must be called before this.

@param dec decoder object @return ::JXL_DEC_SUCCESS if there is a frame to skip, and @ref JXL_DEC_ERROR if the function was not called during frame processing.