JxlEncoderFrameSettingsCreate

Function JxlEncoderFrameSettingsCreate 

pub unsafe extern "C" fn JxlEncoderFrameSettingsCreate(
    enc: *mut JxlEncoder,
    source: *const JxlEncoderFrameSettings,
) -> *mut JxlEncoderFrameSettings
Create a new set of encoder options, with all values initially copied from the @p source options, or set to default if @p source is NULL.

The returned pointer is an opaque struct tied to the encoder and it will be deallocated by the encoder when @ref JxlEncoderDestroy() is called. For functions taking both a @ref JxlEncoder and a @ref JxlEncoderFrameSettings, only @ref JxlEncoderFrameSettings created with this function for the same encoder instance can be used.

@param enc encoder object. @param source source options to copy initial values from, or NULL to get defaults initialized to defaults. @return the opaque struct pointer identifying a new set of encoder options.