pub unsafe extern "C" fn JxlEncoderInitBasicInfo(
info: *mut JxlBasicInfo,
)Expand description
Initializes a @ref JxlBasicInfo struct to default values. For forwards-compatibility, this function has to be called before values are assigned to the struct fields. The default values correspond to an 8-bit RGB image, no alpha or any other extra channels.
@param info global image metadata. Object owned by the caller.