pub unsafe extern "C" fn JxlEncoderSetBasicInfo(
enc: *mut JxlEncoder,
info: *const JxlBasicInfo,
) -> JxlEncoderStatusExpand description
Sets the global metadata of the image encoded by this encoder.
If the @ref JxlBasicInfo contains information of extra channels beyond an
alpha channel, then @ref JxlEncoderSetExtraChannelInfo must be called between
@ref JxlEncoderSetBasicInfo and @ref JxlEncoderAddImageFrame. In order to
indicate extra channels, the value of info.num_extra_channels should be set
to the number of extra channels, also counting the alpha channel if present.
@param enc encoder object. @param info global image metadata. Object owned by the caller and its contents are copied internally. @return ::JXL_ENC_SUCCESS if the operation was successful, ::JXL_ENC_ERROR otherwise