pub unsafe extern "C" fn JxlEncoderSetColorEncoding(
enc: *mut JxlEncoder,
color: *const JxlColorEncoding,
) -> JxlEncoderStatusExpand description
Sets the original color encoding of the image encoded by this encoder. This is an alternative to @ref JxlEncoderSetICCProfile and only one of these two must be used. This one sets the color encoding as a @ref JxlColorEncoding, while the other sets it as ICC binary data. Must be called after @ref JxlEncoderSetBasicInfo.
@param enc encoder object. @param color color encoding. Object owned by the caller and its contents are copied internally. @return ::JXL_ENC_SUCCESS if the operation was successful, @ref JXL_ENC_ERROR otherwise