JxlEncoderSetDebugImageCallback

Function JxlEncoderSetDebugImageCallback 

pub unsafe extern "C" fn JxlEncoderSetDebugImageCallback(
    frame_settings: *mut JxlEncoderFrameSettings,
    callback: JxlDebugImageCallback,
    opaque: *mut c_void,
)
Sets the given debug image callback that will be used by the encoder to output various debug images during encoding.

This only has any effect if the encoder was compiled with the appropriate debug build flags.

@param frame_settings set of options and metadata for this frame. Also includes reference to the encoder object. @param callback used to return the debug image @param opaque user supplied parameter to the image callback