JxlEncoderSetExtraChannelDistance

Function JxlEncoderSetExtraChannelDistance 

pub unsafe extern "C" fn JxlEncoderSetExtraChannelDistance(
    frame_settings: *mut JxlEncoderFrameSettings,
    index: usize,
    distance: f32,
) -> JxlEncoderStatus
Sets the distance level for lossy compression of extra channels. The distance is as in @ref JxlEncoderSetFrameDistance (lower = higher quality). If not set, or if set to the special value -1, the distance that was set with @ref JxlEncoderSetFrameDistance will be used.

@param frame_settings set of options and metadata for this frame. Also includes reference to the encoder object. @param index index of the extra channel to set a distance value for. @param distance the distance value to set. @return ::JXL_ENC_SUCCESS if the operation was successful, @ref JXL_ENC_ERROR otherwise.