JxlEncoderSetOutputProcessor

Function JxlEncoderSetOutputProcessor 

pub unsafe extern "C" fn JxlEncoderSetOutputProcessor(
    enc: *mut JxlEncoder,
    output_processor: JxlEncoderOutputProcessor,
) -> JxlEncoderStatus
Sets the output processor for the encoder. This processor determines how the encoder will handle buffering, writing, seeking (if supported), and setting a finalized position during the encoding process.

This should not be used when using @ref JxlEncoderProcessOutput.

@param enc encoder object. @param output_processor the struct containing the callbacks for managing output. @return ::JXL_ENC_SUCCESS on success, ::JXL_ENC_ERROR on error.