JxlEncoderUseBoxes

Function JxlEncoderUseBoxes 

pub unsafe extern "C" fn JxlEncoderUseBoxes(
    enc: *mut JxlEncoder,
) -> JxlEncoderStatus
Indicates the intention to add metadata boxes. This allows @ref JxlEncoderAddBox to be used. When using this function, then it is required to use @ref JxlEncoderCloseBoxes at the end.

By default the encoder assumes no metadata boxes will be added.

This setting can only be set at the beginning, before encoding starts.

@param enc encoder object.