JxlEncoderUseContainer

Function JxlEncoderUseContainer 

pub unsafe extern "C" fn JxlEncoderUseContainer(
    enc: *mut JxlEncoder,
    use_container: c_int,
) -> JxlEncoderStatus
Forces the encoder to use the box-based container format (BMFF) even when not necessary.

When using @ref JxlEncoderUseBoxes, @ref JxlEncoderStoreJPEGMetadata or @ref JxlEncoderSetCodestreamLevel with level 10, the encoder will automatically also use the container format, it is not necessary to use @ref JxlEncoderUseContainer for those use cases.

By default this setting is disabled.

This setting can only be set at the beginning, before encoding starts.

@param enc encoder object. @param use_container true if the encoder should always output the JPEG XL container format, false to only output it when necessary. @return JXL_ENC_SUCCESS if the operation was successful, JXL_ENC_ERROR otherwise.