#[repr(C)]pub struct JxlFrameHeader {
pub duration: u32,
pub timecode: u32,
pub name_length: u32,
pub is_last: c_int,
pub layer_info: JxlLayerInfo,
}Expand description
The header of one displayed frame or non-coalesced layer.
Fields
duration: u32How long to wait after rendering in ticks. The duration in seconds of a tick is given by tps_numerator and tps_denominator in @ref JxlAnimationHeader.
timecode: u32SMPTE timecode of the current frame in form 0xHHMMSSFF, or 0. The bits are interpreted from most-significant to least-significant as hour, minute, second, and frame. If timecode is nonzero, it is strictly larger than that of a previous frame with nonzero duration. These values are only available if have_timecodes in @ref JxlAnimationHeader is ::JXL_TRUE. This value is only used if have_timecodes in @ref JxlAnimationHeader is ::JXL_TRUE.
name_length: u32Length of the frame name in bytes, or 0 if no name. Excludes null termination character. This value is set by the decoder. For the encoder, this value is ignored and @ref JxlEncoderSetFrameName is used instead to set the name and the length.
is_last: c_intIndicates this is the last animation frame. This value is set by the decoder to indicate no further frames follow. For the encoder, it is not required to set this value and it is ignored, @ref JxlEncoderCloseFrames is used to indicate the last frame to the encoder instead.
layer_info: JxlLayerInfoInformation about the layer in case of no coalescing.