JxlDebugImageCallback

Type Alias JxlDebugImageCallback 

pub type JxlDebugImageCallback = Option<unsafe extern "C" fn(opaque: *mut c_void, label: *const c_char, xsize: usize, ysize: usize, color: *const JxlColorEncoding, pixels: *const u16)>;
Function type for @ref JxlEncoderSetDebugImageCallback.

The callback may be called simultaneously by different threads when using a threaded parallel runner, on different debug images.

@param opaque optional user data, as given to @ref JxlEncoderSetDebugImageCallback. @param label label of debug image, can be used in filenames @param xsize width of debug image @param ysize height of debug image @param color color encoding of debug image @param pixels pixel data of debug image as big-endian 16-bit unsigned samples. The memory is not owned by the user, and is only valid during the time the callback is running.

Aliased Type

pub enum JxlDebugImageCallback {
    None,
    Some(unsafe extern "C" fn(*mut c_void, *const i8, usize, usize, *const JxlColorEncoding, *const u16)),
}

Variants

1.0.0

None

No value.

1.0.0

Some(unsafe extern "C" fn(*mut c_void, *const i8, usize, usize, *const JxlColorEncoding, *const u16))

Some value of type T.