JxlParallelRetCode

Type Alias JxlParallelRetCode 

pub type JxlParallelRetCode = c_int;
Return code used in the JxlParallel* functions as return value. A value of ::JXL_PARALLEL_RET_SUCCESS means success and any other value means error. The special value ::JXL_PARALLEL_RET_RUNNER_ERROR can be used by the runner to indicate any other error.