JxlParallelRunFunction

Type Alias JxlParallelRunFunction 

pub type JxlParallelRunFunction = Option<unsafe extern "C" fn(jpegxl_opaque: *mut c_void, value: u32, thread_id: usize)>;
Parallel run data processing callback. See @ref JxlParallelRunner for details.

This function MUST be called once for every number in the range [start_range, end_range) (including start_range but not including end_range) passing this number as the @p value. Calls for different value may be executed from different threads in parallel.

@param jpegxl_opaque the @p jpegxl_opaque handle provided to @ref JxlParallelRunner() must be passed here. @param value the number in the range [start_range, end_range) of the call. @param thread_id the thread number where this function is being called from. This must be lower than the @p num_threads value passed to @ref JxlParallelRunInit.

Aliased Type

pub enum JxlParallelRunFunction {
    None,
    Some(unsafe extern "C" fn(*mut c_void, u32, usize)),
}

Variants

1.0.0

None

No value.

1.0.0

Some(unsafe extern "C" fn(*mut c_void, u32, usize))

Some value of type T.