pub unsafe extern "C" fn JxlEncoderCloseInput(enc: *mut JxlEncoder)Expand description
Closes any input to the encoder, equivalent to calling @ref JxlEncoderCloseFrames as well as calling @ref JxlEncoderCloseBoxes if needed. No further input of any kind may be given to the encoder, but further @ref JxlEncoderProcessOutput calls should be done to create the final output.
The requirements of both @ref JxlEncoderCloseFrames and @ref JxlEncoderCloseBoxes apply to this function. Either this function or the other two must be called after the final frame and/or box, and the next @ref JxlEncoderProcessOutput call, or the codestream won’t be encoded correctly.
@param enc encoder object.