pub unsafe extern "C" fn JxlEncoderSetExtraChannelInfo(
enc: *mut JxlEncoder,
index: usize,
info: *const JxlExtraChannelInfo,
) -> JxlEncoderStatusExpand description
Sets information for the extra channel at the given index. The index must be smaller than num_extra_channels in the associated @ref JxlBasicInfo.
@param enc encoder object @param index index of the extra channel to set. @param info global extra channel metadata. Object owned by the caller and its contents are copied internally. @return ::JXL_ENC_SUCCESS on success, ::JXL_ENC_ERROR on error