pub unsafe extern "C" fn JxlEncoderSetExtraChannelName(
enc: *mut JxlEncoder,
index: usize,
name: *const c_char,
size: usize,
) -> JxlEncoderStatusExpand description
Sets the name for the extra channel at the given index in UTF-8. The index must be smaller than the num_extra_channels in the associated @ref JxlBasicInfo.
TODO(lode): remove size parameter for consistency with @ref JxlEncoderSetFrameName
@param enc encoder object @param index index of the extra channel to set. @param name buffer with the name of the extra channel. @param size size of the name buffer in bytes, not counting the terminating character. @return JXL_ENC_SUCCESS on success, JXL_ENC_ERROR on error