pub unsafe extern "C" fn JxlEncoderSetFrameBitDepth(
frame_settings: *mut JxlEncoderFrameSettings,
bit_depth: *const JxlBitDepth,
) -> JxlEncoderStatusExpand description
Sets the bit depth of the input buffer.
For float pixel formats, only the default @ref JXL_BIT_DEPTH_FROM_PIXEL_FORMAT setting is allowed, while for unsigned pixel formats, ::JXL_BIT_DEPTH_FROM_CODESTREAM setting is also allowed. See the comment on @ref JxlEncoderAddImageFrame for the effects of the bit depth setting.
@param frame_settings set of options and metadata for this frame. Also includes reference to the encoder object. @param bit_depth the bit depth setting of the pixel input @return ::JXL_ENC_SUCCESS on success, ::JXL_ENC_ERROR on error