pub unsafe extern "C" fn JxlEncoderSetFrameName(
frame_settings: *mut JxlEncoderFrameSettings,
frame_name: *const c_char,
) -> JxlEncoderStatusExpand description
Sets the name of the animation frame. This function is optional, frames are not required to have a name. This setting is a part of the frame header, and the same principles as for @ref JxlEncoderSetFrameHeader apply. The name_length field of @ref JxlFrameHeader is ignored by the encoder, this function determines the name length instead as the length in bytes of the C string.
The maximum possible name length is 1071 bytes (excluding terminating null character).
Calling @ref JxlEncoderSetFrameHeader clears any name that was previously set.
@param frame_settings set of options and metadata for this frame. Also includes reference to the encoder object. @param frame_name name of the next frame to be encoded, as a UTF-8 encoded C string (zero terminated). Owned by the caller, and copied internally. @return ::JXL_ENC_SUCCESS on success, ::JXL_ENC_ERROR on error