#[repr(C)]pub struct JxlColorProfile {
pub icc: JxlColorProfile__bindgen_ty_1,
pub color_encoding: JxlColorEncoding,
pub num_channels: usize,
}Expand description
Represents an input or output colorspace to a color transform, as a serialized ICC profile.
Fields
icc: JxlColorProfile__bindgen_ty_1color_encoding: JxlColorEncodingStructured representation of the colorspace, if applicable. If all fields are different from their “unknown” value, then this is equivalent to the ICC representation of the colorspace. If some are “unknown”, those that are not are still valid and can still be used on their own if they are useful.
num_channels: usizeNumber of components per pixel. This can be deduced from the other representations of the colorspace but is provided for convenience and validation.