#[repr(C)]pub struct JxlMemoryManagerStruct {
pub opaque: *mut c_void,
pub alloc: jpegxl_alloc_func,
pub free: jpegxl_free_func,
}Expand description
Memory Manager struct. These functions, when provided by the caller, will be used to handle memory allocations.
Fields
opaque: *mut c_voidThe opaque pointer that will be passed as the first parameter to all the functions in this struct.
alloc: jpegxl_alloc_funcMemory allocation function. This can be NULL if and only if also the free() member in this class is NULL. All dynamic memory will be allocated and freed with these functions if they are not NULL, otherwise with the standard malloc/free.
free: jpegxl_free_funcFree function matching the alloc() member.